@@ -60,6 +60,7 @@ import com.openexchange.groupware.delete.DeleteListener;
 import com.openexchange.mail.service.MailService;
 import com.openexchange.mailaccount.MailAccountDeleteListener;
 import com.openexchange.osgi.HousekeepingActivator;
+import com.openexchange.pns.PushNotificationService;
 import com.openexchange.push.PushListenerService;
 import com.openexchange.push.PushManagerService;
 import com.openexchange.push.mail.notify.MailNotifyPushDeleteListener;
@@ -137,6 +138,7 @@ public final class MailNotifyActivator extends HousekeepingActivator {
             this.registry = registry;
 
             // Track optional services
+            trackService(PushNotificationService.class);
             openTrackers();
 
             // Register push manager
